Documentation
¶
Overview ¶
Copyright 2026- The sacloud/simple-notification-api-go Authors
Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with the License. You may obtain a copy of the License at
http://www.apache.org/licenses/LICENSE-2.0
Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for the specific language governing permissions and limitations under the License.
Index ¶
- Constants
- func NewClient(client *saclient.Client) (*v1.Client, error)
- func NewClientWithAPIRootURL(client *saclient.Client, apiRootURL string) (*v1.Client, error)
- type DestinationAPI
- type DestinationOp
- func (o *DestinationOp) Create(ctx context.Context, request v1.PostCommonServiceItemRequest) (*v1.CreateCommonServiceItemCreated, error)
- func (o *DestinationOp) Delete(ctx context.Context, id string) error
- func (o *DestinationOp) List(ctx context.Context) (*v1.ListCommonServiceItemsResponse, error)
- func (o *DestinationOp) Read(ctx context.Context, id string) (*v1.GetCommonServiceItemOK, error)
- func (o *DestinationOp) ReadStatus(ctx context.Context, id string) (*v1.GetCommonServiceItemStatusResponse, error)
- func (o *DestinationOp) Update(ctx context.Context, id string, request v1.PutCommonServiceItemRequest) (*v1.UpdateCommonServiceItemOK, error)
- type Error
- type GroupAPI
- type GroupOp
- func (o *GroupOp) Create(ctx context.Context, request v1.PostCommonServiceItemRequest) (*v1.CreateCommonServiceItemCreated, error)
- func (o *GroupOp) Delete(ctx context.Context, id string) error
- func (o *GroupOp) List(ctx context.Context) (*v1.ListCommonServiceItemsResponse, error)
- func (o *GroupOp) Read(ctx context.Context, id string) (*v1.GetCommonServiceItemOK, error)
- func (o *GroupOp) SendMessage(ctx context.Context, id string, request v1.SendNotificationMessageRequest) (*v1.SendNotificationMessageResponse, error)
- func (o *GroupOp) Update(ctx context.Context, id string, request v1.PutCommonServiceItemRequest) (*v1.UpdateCommonServiceItemOK, error)
- type HistoryAPI
- type HistoryOp
- type RoutingAPI
- type RoutingOp
- func (o *RoutingOp) Create(ctx context.Context, request v1.PostCommonServiceItemRequest) (*v1.CreateCommonServiceItemCreated, error)
- func (o *RoutingOp) Delete(ctx context.Context, id string) error
- func (o *RoutingOp) List(ctx context.Context) (*v1.ListCommonServiceItemsResponse, error)
- func (o *RoutingOp) ListSource(ctx context.Context) (*v1.ListSourcesResponse, error)
- func (o *RoutingOp) Read(ctx context.Context, id string) (*v1.GetCommonServiceItemOK, error)
- func (o *RoutingOp) Reorder(ctx context.Context, request v1.PutCommonServiceItemRoutingReorderRequest) (*v1.ReorderRoutingAccepted, error)
- func (o *RoutingOp) Update(ctx context.Context, id string, request v1.PutCommonServiceItemRequest) (*v1.UpdateCommonServiceItemOK, error)
Constants ¶
const Version = "0.3.0"
Variables ¶
This section is empty.
Functions ¶
Types ¶
type DestinationAPI ¶
type DestinationAPI interface {
List(ctx context.Context) (*v1.ListCommonServiceItemsResponse, error)
Create(ctx context.Context, request v1.PostCommonServiceItemRequest) (*v1.CreateCommonServiceItemCreated, error)
Read(ctx context.Context, id string) (*v1.GetCommonServiceItemOK, error)
Update(ctx context.Context, id string, request v1.PutCommonServiceItemRequest) (*v1.UpdateCommonServiceItemOK, error)
Delete(ctx context.Context, id string) error
ReadStatus(ctx context.Context, id string) (*v1.GetCommonServiceItemStatusResponse, error)
}
func NewDestinationOp ¶
func NewDestinationOp(client *v1.Client) DestinationAPI
type DestinationOp ¶
type DestinationOp struct {
// contains filtered or unexported fields
}
func (*DestinationOp) Create ¶
func (o *DestinationOp) Create(ctx context.Context, request v1.PostCommonServiceItemRequest) (*v1.CreateCommonServiceItemCreated, error)
func (*DestinationOp) List ¶
func (o *DestinationOp) List(ctx context.Context) (*v1.ListCommonServiceItemsResponse, error)
func (*DestinationOp) Read ¶
func (o *DestinationOp) Read(ctx context.Context, id string) (*v1.GetCommonServiceItemOK, error)
func (*DestinationOp) ReadStatus ¶
func (o *DestinationOp) ReadStatus(ctx context.Context, id string) (*v1.GetCommonServiceItemStatusResponse, error)
func (*DestinationOp) Update ¶
func (o *DestinationOp) Update(ctx context.Context, id string, request v1.PutCommonServiceItemRequest) (*v1.UpdateCommonServiceItemOK, error)
type GroupAPI ¶
type GroupAPI interface {
List(ctx context.Context) (*v1.ListCommonServiceItemsResponse, error)
Create(ctx context.Context, request v1.PostCommonServiceItemRequest) (*v1.CreateCommonServiceItemCreated, error)
Read(ctx context.Context, id string) (*v1.GetCommonServiceItemOK, error)
Update(ctx context.Context, id string, request v1.PutCommonServiceItemRequest) (*v1.UpdateCommonServiceItemOK, error)
Delete(ctx context.Context, id string) error
SendMessage(ctx context.Context, id string,
request v1.SendNotificationMessageRequest) (*v1.SendNotificationMessageResponse, error)
}
func NewGroupOp ¶
type GroupOp ¶
type GroupOp struct {
// contains filtered or unexported fields
}
func (*GroupOp) Create ¶
func (o *GroupOp) Create(ctx context.Context, request v1.PostCommonServiceItemRequest) (*v1.CreateCommonServiceItemCreated, error)
func (*GroupOp) SendMessage ¶
func (o *GroupOp) SendMessage(ctx context.Context, id string, request v1.SendNotificationMessageRequest) (*v1.SendNotificationMessageResponse, error)
type HistoryAPI ¶
type HistoryAPI interface {
List(ctx context.Context) (*v1.ListSimpleNotificationHistoriesResponse, error)
Read(ctx context.Context, id string) (*v1.GetSimpleNotificationHistoryResponse, error)
}
func NewHistoryOp ¶
func NewHistoryOp(client *v1.Client) HistoryAPI
type HistoryOp ¶
type HistoryOp struct {
// contains filtered or unexported fields
}
type RoutingAPI ¶
type RoutingAPI interface {
List(ctx context.Context) (*v1.ListCommonServiceItemsResponse, error)
Create(ctx context.Context, request v1.PostCommonServiceItemRequest) (*v1.CreateCommonServiceItemCreated, error)
Read(ctx context.Context, id string) (*v1.GetCommonServiceItemOK, error)
Update(ctx context.Context, id string, request v1.PutCommonServiceItemRequest) (*v1.UpdateCommonServiceItemOK, error)
Delete(ctx context.Context, id string) error
Reorder(ctx context.Context, request v1.PutCommonServiceItemRoutingReorderRequest) (*v1.ReorderRoutingAccepted, error)
ListSource(ctx context.Context) (*v1.ListSourcesResponse, error)
}
func NewRoutingOp ¶
func NewRoutingOp(client *v1.Client) RoutingAPI
type RoutingOp ¶
type RoutingOp struct {
// contains filtered or unexported fields
}
func (*RoutingOp) Create ¶
func (o *RoutingOp) Create(ctx context.Context, request v1.PostCommonServiceItemRequest) (*v1.CreateCommonServiceItemCreated, error)
func (*RoutingOp) ListSource ¶
func (*RoutingOp) Reorder ¶
func (o *RoutingOp) Reorder(ctx context.Context, request v1.PutCommonServiceItemRoutingReorderRequest) (*v1.ReorderRoutingAccepted, error)
Source Files
¶
Click to show internal directories.
Click to hide internal directories.